pub struct Tally {
pub standard: Vec<Locus>,
pub subregion: Option<(Locus, Subregion)>,
}Expand description
The partial score carried by an extended hyphenation pattern.
Fields
standard: Vec<Locus>The pattern tally, equivalent to that found in standard patterns.
subregion: Option<(Locus, Subregion)>An optional subregion which may replace part of the string around the opportunity.